/**
 * Find a least lexicographical match for the longest common subsequence.
 *
 * The returned value is an tuple array (called `pairs`), where each element (pair=[i,j]) indicates that
 * the i-th element of the first sequence is paired with the j-th element of the second sequence.
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function findMinLexicographicalLCS(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): Array<[number, number]>;
/**
 * Find the length of the longest common subsequence.
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function findLengthOfLCS(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): number;
/**
 * Find Longest Common Subsequence with Dynamic Programming.
 *
 * Let dp(i,j) denote the longest common subsequence of {a1,a2,...,ai} and {b1,b2,...,bj}, it is not
 * difficult to derive the transition equation:
 *
 *    dp(i,j) = max{dp(i-1,j), dp(i,j-1), dp(i-1,j-1)+f(i,j)}, where f(i,j) = 1 if ai=aj else 0
 *
 * ### Optimization
 *
 * let dp(j) denote the longest common subsequence of {a1, a2, ...aN1} and {b1, b2, ...,bj}, then we
 * should update in reverse order, similar to the rolling array of the knapsack problem.
 *
 * The time complexity is still O(N1xN2), but the space complexity is optimized to O(N2) now.
 *
 * @param N1
 * @param N2
 * @param isEqual
 * @returns
 * @see https://me.guanghechen.com/post/algorithm/lcs/
 */
export declare function findLCSOfEveryRightPrefix(N1: number, N2: number, isEqual: (x: number, y: number) => boolean): Uint32Array | null;
